/**
  *  \file client/tiles/nheader.cc
  */

#include "client/tiles/nheader.h"
#include "cpluslib/format.h"
#include "game/config.h"
#include "game/planet.h"
#include "game/racename.h"
#include "game/ship.h"
#include "game/spec.h"
#include "game/tables.h"
#include "gfx/palette.h"
#include "resmgr/resid.h"
#include "resmgr/resmgr.h"
#include "ui/uiglobal.h"
#include "ui/util.h"
#include "util/nls.h"


WNarrowHeaderTile::WNarrowHeaderTile(GObjectType& type)
    : WObjectTypeObserverTile(GfxPoint(250, 99), // FIXME?
                              type)
{ }

void
WNarrowHeaderTile::drawData(GfxCanvas& can)
{
    /* Picture is 93 pixels, with frame 95, with two pixels space on each side: 99. */
    /*  ###### Name           Name
        ###### (Id #10)       (Id #10)
        ###### 75F, warm      EMERALD
        ###### Tholians       Tholians
        ###### Soldier        Soldier
        ###### */

    // Acquire data
    ResId image;
    string_t name, type;
    int id, owner, level;
    if (GPlanet* pl = dynamic_cast<GPlanet*>(getObject())) {
        name = pl->getName();
        id = pl->getId();
        if (pl->getTemperature().isKnown()) {
            type = format(_("%dF, %s"), pl->getTemperature(), getTemperatureName(pl->getTemperature()));
            image = ResId(res::planet, pl->getTemperature(), pl->getId());
        } else {
            image = ResId(res::planet);
        }
        owner = pl->hasAnyPlanetData() ? pl->getOwner() : -1;
        level = pl->unit_scores.getScore(planet_score_definitions.lookupScore(ScoreId_ExpLevel));
    } else if (GShip* sh = dynamic_cast<GShip*>(getObject())) {
        name = sh->getName();
        id = sh->getId();
        if (int h = sh->getHullId()) {
            type = getHull(h).getName();
            image = ResId(res::ship, getHull(h).getPicture(), h);
        } else {
            type = _("Unknown type");
            image = ResId("nvc");
        }
        // FIXME: guessed position, controller!!!!!!!
        owner = sh->getOwner();
        level = sh->unit_scores.getScore(ship_score_definitions.lookupScore(ScoreId_ExpLevel));
    } else {
        getSkin().drawBackground(can, extent);
        return;
    }

    // Draw it
    UISkin& sk = getSkin();
    sk.startDraw();
    drawFrameDown(can, GfxRect(extent.x + 2, extent.y + 2, 107, 95));

    Ptr<GfxPixmap> pix = ResManager::getInstance().getPixmap(image);
    if (pix)
        pix->blitSized(can, extent.x + 3, extent.y + 3, 105, 93);
    else
        drawSolidBar(can, GfxRect(extent.x + 3, extent.y + 3, 105, 93), standard_colors[COLOR_BLACK]);

    // Text
    int x = extent.x + 115;
    int y = extent.y + 2;
    int w = extent.w - 115;
    int dy = font_heights[FONT_NORMAL];

    sk.setColor(UIColor::tc_White);
    sk.outTextF(can, FONT_NORMAL, x, y, w, name);
    y += dy;

    sk.setColor(UIColor::tc_Yellow);
    sk.outTextF(can, FONT_NORMAL, x, y, w, format(_("(Id #%d)"), id));
    y += dy;

    sk.setColor(UIColor::tc_Static);
    sk.outTextF(can, FONT_NORMAL, x, y, w, type);
    y += dy;

    if (owner == 0)
        sk.outTextF(can, FONT_NORMAL, x, y, w, _("unowned"));
    else if (owner > 0)
        sk.outTextF(can, FONT_NORMAL, x, y, w, player_racenames.getShortName(owner));
    y += dy;

    if (level >= 0)
        sk.outTextF(can, FONT_NORMAL, x, y, w, getExperienceLevelName(level));
}
