/**
  *  \file client/tiles/planetbase.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planetbase.h"
#include "game/planet.h"
#include "util/nls.h"
#include "ui/widgets.h"

/**************************** WPlanetBaseTile ****************************/

/** \class WPlanetBaseTile
    \brief Planet/Base Tile

    On a planet, displays whether there is a base, and offers to build
    one. On a starbase, offers to go to the planet. Also offers to
    scan the planet. */

/** Constructor. \param on_base true if we are on the starbase screen,
    false if on planet */
WPlanetBaseTile::WPlanetBaseTile(GObjectType& type, bool on_base)
    : WObjectTypeObserverTile(GfxPoint(315, font_heights[FONT_TITLE]*2 + 2), type),
      on_base(on_base)
{
    setLayout(RightJustified, 0, false);
    const int he = font_heights[FONT_TITLE];
    addControl(GfxRect(0, 0, 30, he),    h.add(new UIButton("F5", SDLK_F5)));
    addControl(GfxRect(0, he+2, 30, he), h.add(new UIButton("F8", SDLK_F8)));
}

void
WPlanetBaseTile::drawData(GfxCanvas& can)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (!p)
        return;
    
    const int w = getExtent().w - 35;
    const char* s;

    setColor(UIColor::tc_Heading);
    getSkin().getParameters().just_x = 2;
    outTextF(can, FONT_TITLE, w, 0, w, _("Planet overview"));

    if (on_base) {
        s = _("Go to planet");
    } else if (p->hasBase()) {
        s = _("Go to starbase");
    } else if (p->isBuildingBase()) {
        setColor(UIColor::tc_Green);
        s = _("Starbase being built...");
    } else {
        s = _("Build starbase");
    }

    outTextF(can, FONT_TITLE, w, font_heights[FONT_TITLE]+2, w, s);
}
