/**
  *  \file game/sim-if.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/sim-if.h"
#include "cpluslib/format.h"
#include "util/nls.h"

/*! \class GSimulatorNullInterface
    \brief Null Game/Simulator Interface

    This is a simulator/game interface usable to run the simulator
    standalone, without needing any game data. */

string_t
GSimulatorNullInterface::getPlanetName(int id)
{
    return string_t(format(_("Planet #%d"), id));
}

int
GSimulatorNullInterface::getShipOwner(int /*id*/)
{
    return 0;
}

bool
GSimulatorNullInterface::isGameAvailable()
{
    return false;
}

bool
GSimulatorNullInterface::updateFromGame(GSimShip& /*sh*/)
{
    return false;
}
bool
GSimulatorNullInterface::updateToGame(const GSimShip& /*sh*/)
{
    return false;
}
bool
GSimulatorNullInterface::isGamePlanet(const GSimPlanet& /*pl*/)
{
    return false;
}

bool
GSimulatorNullInterface::updateFromGame(GSimPlanet& /*pl*/)
{
    return false;
}

bool
GSimulatorNullInterface::updateToGame(const GSimPlanet& /*pl*/)
{
    return false;
}

GSimulatorNullInterface::ShipRelation
GSimulatorNullInterface::getShipRelation(const GSimShip& /*sh*/)
{
    return ShipIsUnknown;
}

bool
GSimulatorNullInterface::selectGameShip(const GSimShip& /*sh*/)
{
    return false;
}
