/**
  *  \file int/if/planetif.h
  *  \brief Interpreter Game Interface: Planets
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_PLANETIF_H
#define PCC_V2_INT_IF_PLANETIF_H

#include "cpluslib/types.h"
#include "int/context.h"
#include "cpluslib/string.h"

class IntValue;
class IntArgBlock;
class GPlanet;

IntValue*   IFPlanetGet(IntArgBlock& args);
IntContext* IFPlanetMake();

/** Ship context. */
class IntPlanetContext : public IntContext {
    int pid;
 public:
    IntPlanetContext(int pid);
    ~IntPlanetContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
    GObject*  getObject();
    string_t  toString(bool readable);
    void      store(IntTagNode& sv, Stream& aux);
};

enum IntPlanetProperty {
    ippBaseDefenseWanted,
    ippBaseFlag,
    ippBaseStr,
    ippColonistChange,
    ippColonistChangeStr,
    ippColonistHappy,
    ippColonistHappyStr,
    ippColonistSupported,
    ippColonistTax,
    ippColonists,
    ippDefense,
    ippDefenseMax,
    ippDefenseWanted,
    ippDensityD,
    ippDensityM,
    ippDensityN,
    ippDensityT,
    ippFCode,
    ippFactories,
    ippFactoriesMax,
    ippFactoriesWanted,
    ippGroundD,
    ippGroundM,
    ippGroundN,
    ippGroundT,
    ippId,
    ippIndustry,
    ippIndustryCode,
    ippLevel,
    ippLocX,
    ippLocY,
    ippMarked,
    ippMinedD,
    ippMinedM,
    ippMinedN,
    ippMinedStr,
    ippMinedT,
    ippMines,
    ippMinesMax,
    ippMinesWanted,
    ippMoney,
    ippName,
    ippNativeChange,
    ippNativeChangeStr,
    ippNativeGov,
    ippNativeGovCode,
    ippNativeHappy,
    ippNativeHappyStr,
    ippNativeRace,
    ippNativeRaceCode,
    ippNativeTax,
    ippNatives,
    ippOrbitingEnemies,
    ippOrbitingOwn,
    ippOrbitingShips,
    ippPlayed,
    ippSupplies,
    ippTask,
    ippTaskBase,
    ippTemp,
    ippTempStr
};

IntValue* getPlanetProperty(const GPlanet& pl, IntPlanetProperty ipp);
void      setPlanetProperty(GPlanet& pl, IntPlanetProperty ipp, IntValue* value);

#endif
